#' Index of US Industrial Production
#'
#' Index of US industrial production (1985 = 100).
#'
#' This is a transformation into simple data.frame
#' of data `USProdIndex` in package 'AER'.
#'
#' @name us_indus_prod
#' @docType data
#' @keywords datasets
#' @usage data(us_indus_prod)
#' @format A data frame with 256 rows and 3 variables
NULL

#' Dummy dataset for barchart
#'
#' A dataset containing 2 categorical and an integer variables:
#'
#' * browser web browser
#' * serie id of series
#' * value integer values
#'
#' @name browser_data
#' @docType data
#' @keywords datasets
#' @usage data(browser_data)
#' @format A data frame with 18 rows and 3 variables
NULL

#' Dummy dataset for barchart
#'
#' A dataset containing a date, a categorical and an integer variables:
#'
#' * date date values
#' * browser web browser
#' * freq values in percent
#'
#' @name browser_ts
#' @docType data
#' @keywords datasets
#' @usage data(browser_ts)
#' @format A data frame with 36 rows and 3 variables
NULL
